@@ -483,7 +483,7 @@ assessTemporalIndependence <- function(intable,
                                         intable[, stationCol]           == intable[current_row, stationCol]  &        # same station
                                         intable[, cameraCol]            == intable[current_row, cameraCol]   &        # same camera
                                         intable$DateTimeOriginal        >= intable$DateTimeOriginal[current_row]  &
-                                        !intable$independent)                                        # not independent
+                                        !isTRUE(intable$independent))                                        # not independent
       
     } else {
       which_records_to_group <- which(intable[, columnOfInterest]       == intable[current_row, columnOfInterest] &   # same species
@@ -1321,7 +1321,8 @@ dataFrameTibbleCheck <- function(df,
     if(data.table::is.data.table(df)) {
       if(data_table_allowed) {
         message (paste(substitute(df), "was converted from data.table to data.frame"), call. = FALSE)
-        df <- as.data.frame(df)
+        #df <- as.data.frame(df)
+        df <- setDF(df)
       } else {
         stop (paste(substitute(df), "is a data.table Please provide a data.frame instead (use read.csv() or as.data.frame())"), call. = FALSE)
       }
